@@ -1,6 +1,9 @@
-use fltk::{enums::*, prelude::*, *};
+use egui_backend::{
+    egui,
+    fltk::{enums::*, prelude::*, *},
+    gl, DpiScaling,
+};
 use fltk_egui as egui_backend;
-use egui_backend::{DpiScaling, egui, gl};
 use std::rc::Rc;
 use std::{cell::RefCell, time::Instant};
 
@@ -26,7 +29,8 @@ fn main() {
     main_win.show();
     glut_win.make_current();
 
-    let (painter, egui_input_state) = egui_backend::with_fltk(&mut glut_win, DpiScaling::Custom(1.5));
+    let (painter, egui_input_state) =
+        egui_backend::with_fltk(&mut glut_win, DpiScaling::Custom(1.5));
     let mut egui_ctx = egui::CtxRef::default();
 
     let state_rc = Rc::from(RefCell::from(egui_input_state));
@@ -44,12 +48,8 @@ fn main() {
             | enums::Event::Resize
             | enums::Event::Move
             | enums::Event::Drag => {
-                egui_backend::input_to_egui(
-                    &mut w,
-                    ev,
-                    &mut state.borrow_mut(),
-                    &mut painter.borrow_mut(),
-                );
+                let mut state = state.borrow_mut();
+                state.fuse_input(&mut w, ev, &mut painter.borrow_mut());
                 true
             }
             _ => false,
@@ -73,6 +73,7 @@ fn main() {
             gl::ClearColor(0.6, 0.3, 0.3, 1.0);
             gl::Clear(gl::COLOR_BUFFER_BIT);
         }
+
         egui::CentralPanel::default().show(&egui_ctx, |ui| {
             ui.heading("My egui Application");
             ui.horizontal(|ui| {
@@ -95,12 +96,7 @@ fn main() {
         });
 
         let (egui_output, paint_cmds) = egui_ctx.end_frame();
-        egui_backend::translate_cursor(&mut glut_win, &mut state.fuse_cursor, egui_output.cursor_icon);
-
-        //Handle cut, copy text from egui
-        if !egui_output.copied_text.is_empty() {
-            egui_backend::copy_to_clipboard(&mut state.clipboard, egui_output.copied_text);
-        }
+        state.fuse_output(&mut glut_win, &egui_output);
 
         let paint_jobs = egui_ctx.tessellate(paint_cmds);
 
