@@ -1,9 +1,9 @@
 // Draws a simple white triangle
 // based on the example from:
 // https://github.com/brendanzab/gl-rs/blob/master/gl/examples/triangle.rs
-use egui_backend::gl;
+
+use egui_backend::gl::types::*;
 use fltk_egui as egui_backend;
-use gl::types::*;
 use std::ffi::CString;
 use std::mem;
 use std::ptr;
