@@ -117,7 +117,7 @@ pub struct Painter {
     // not sure in fltk GlutWindow, enabled by default?.
     pub gl_sync_fence: GLsync,
     egui_texture_version: Option<u64>,
-    user_textures: Vec<UserTexture>,
+    user_textures: Vec<Option<UserTexture>>,
     pub pixels_per_point: f32,
     pub canvas_size: (i32, i32),
     pub screen_rect: Rect,
@@ -269,13 +269,13 @@ impl Painter {
         }
 
         let id = egui::TextureId::User(self.user_textures.len() as u64);
-        self.user_textures.push(UserTexture {
+        self.user_textures.push(Some(UserTexture {
             size,
             pixels,
             texture: None,
             filtering,
             dirty: true,
-        });
+        }));
         id
     }
 
@@ -295,7 +295,6 @@ impl Painter {
 
         unsafe {
             gl::BindTexture(gl::TEXTURE_2D, self.egui_texture);
-
             let level = 0;
             let internal_format = gl::RGBA;
             let border = 0;
@@ -319,10 +318,11 @@ impl Painter {
 
     fn upload_user_textures(&mut self) {
         unsafe {
-            for user_texture in &mut self.user_textures {
-                if !user_texture.texture.is_none() && !user_texture.dirty {
+            for user_texture in self.user_textures.iter_mut().flatten() {
+                if user_texture.texture.is_some() && !user_texture.dirty {
                     continue;
                 }
+
                 let pixels = std::mem::take(&mut user_texture.pixels);
 
                 if user_texture.texture.is_none() {
@@ -383,14 +383,16 @@ impl Painter {
         }
     }
 
-    fn get_texture(&self, texture_id: egui::TextureId) -> GLuint {
+    fn get_texture(&self, texture_id: egui::TextureId) -> Option<GLuint> {
         match texture_id {
-            egui::TextureId::Egui => self.egui_texture,
+            egui::TextureId::Egui => Some(self.egui_texture),
             egui::TextureId::User(id) => {
                 let id = id as usize;
-                assert!(id < self.user_textures.len());
-                let texture = self.user_textures[id].texture;
-                texture.expect("Should have been uploaded")
+                if id < self.user_textures.len() {
+                    let user_texture = self.user_textures[id].as_ref()?;
+                    return user_texture.texture;
+                }
+                None
             }
         }
     }
@@ -400,16 +402,34 @@ impl Painter {
             egui::TextureId::Egui => {}
             egui::TextureId::User(id) => {
                 let id = id as usize;
-                assert!(id < self.user_textures.len());
-                self.user_textures[id].pixels = Vec::with_capacity(pixels.len() * 4);
-
-                for p in pixels {
-                    self.user_textures[id].pixels.push(p[0]);
-                    self.user_textures[id].pixels.push(p[1]);
-                    self.user_textures[id].pixels.push(p[2]);
-                    self.user_textures[id].pixels.push(p[3]);
+                if id < self.user_textures.len() {
+                    if let Some(user_textures) = self.user_textures[id].as_mut() {
+                        user_textures.pixels = Vec::with_capacity(pixels.len() * 4);
+                        for p in pixels {
+                            user_textures.pixels.push(p[0]);
+                            user_textures.pixels.push(p[1]);
+                            user_textures.pixels.push(p[2]);
+                            user_textures.pixels.push(p[3]);
+                        }
+                        user_textures.dirty = true
+                    }
                 }
-                self.user_textures[id].dirty = true;
+            }
+        }
+    }
+
+    pub fn free_user_texture(&mut self, id: egui::TextureId) {
+        if let egui::TextureId::User(id) = id {
+            let idx = id as usize;
+            if idx < self.user_textures.len() {
+                if let Some(UserTexture {
+                    texture: Some(texture),
+                    ..
+                }) = self.user_textures[idx].as_mut()
+                {
+                    unsafe { gl::DeleteTextures(1, texture) }
+                }
+                self.user_textures[idx] = None
             }
         }
     }
@@ -460,29 +480,33 @@ impl Painter {
             let screen_y = canvas_height as f32;
 
             for ClippedMesh(clip_rect, mesh) in meshes {
-                gl::BindTexture(gl::TEXTURE_2D, self.get_texture(mesh.texture_id));
-                let clip_min_x = pixels_per_point * clip_rect.min.x;
-                let clip_min_y = pixels_per_point * clip_rect.min.y;
-                let clip_max_x = pixels_per_point * clip_rect.max.x;
-                let clip_max_y = pixels_per_point * clip_rect.max.y;
-                let clip_min_x = clip_min_x.clamp(0.0, x);
-                let clip_min_y = clip_min_y.clamp(0.0, y);
-                let clip_max_x = clip_max_x.clamp(clip_min_x, screen_x);
-                let clip_max_y = clip_max_y.clamp(clip_min_y, screen_y);
-                let clip_min_x = clip_min_x.round() as i32;
-                let clip_min_y = clip_min_y.round() as i32;
-                let clip_max_x = clip_max_x.round() as i32;
-                let clip_max_y = clip_max_y.round() as i32;
+                if let Some(texture_id) = self.get_texture(mesh.texture_id) {
+                    gl::BindTexture(gl::TEXTURE_2D, texture_id);
+                    let clip_min_x = pixels_per_point * clip_rect.min.x;
+                    let clip_min_y = pixels_per_point * clip_rect.min.y;
+                    let clip_max_x = pixels_per_point * clip_rect.max.x;
+                    let clip_max_y = pixels_per_point * clip_rect.max.y;
+                    let clip_min_x = clip_min_x.clamp(0.0, x);
+                    let clip_min_y = clip_min_y.clamp(0.0, y);
+                    let clip_max_x = clip_max_x.clamp(clip_min_x, screen_x);
+                    let clip_max_y = clip_max_y.clamp(clip_min_y, screen_y);
+                    let clip_min_x = clip_min_x.round() as i32;
+                    let clip_min_y = clip_min_y.round() as i32;
+                    let clip_max_x = clip_max_x.round() as i32;
+                    let clip_max_y = clip_max_y.round() as i32;
 
-                //scissor Y coordinate is from the bottom
-                gl::Scissor(
-                    clip_min_x,
-                    canvas_height - clip_max_y,
-                    clip_max_x - clip_min_x,
-                    clip_max_y - clip_min_y,
-                );
+                    //scissor Y coordinate is from the bottom
+                    gl::Scissor(
+                        clip_min_x,
+                        canvas_height - clip_max_y,
+                        clip_max_x - clip_min_x,
+                        clip_max_y - clip_min_y,
+                    );
 
-                self.paint_mesh(&mesh);
+                    self.paint_mesh(&mesh);
+                } else {
+                    continue;
+                }
             }
 
             gl::Disable(gl::SCISSOR_TEST);
@@ -617,11 +641,17 @@ impl Painter {
     pub fn cleanup(&self) {
         unsafe {
             gl::DeleteSync(self.gl_sync_fence);
+            for user in self.user_textures.iter().flatten() {
+                if let Some(texture) = user.texture {
+                    gl::DeleteTextures(1, &texture);
+                }
+            }
             gl::DeleteProgram(self.program);
             gl::DeleteBuffers(1, &self.pos_buffer);
             gl::DeleteBuffers(1, &self.tc_buffer);
             gl::DeleteBuffers(1, &self.color_buffer);
             gl::DeleteBuffers(1, &self.index_buffer);
+            gl::DeleteTextures(1, &self.egui_texture);
             gl::DeleteVertexArrays(1, &self.vertex_array);
         }
     }
@@ -629,6 +659,6 @@ impl Painter {
 
 impl Drop for Painter {
     fn drop(&mut self) {
-        self.cleanup();
+        self.cleanup()
     }
 }
